# model-explorer-onnx
ONNX Adapter for model-explorer

## Installation

```bash
pip install --upgrade model-explorer-onnx
```

## Usage

```bash
model-explorer model.onnx --extensions=model_explorer_onnx
```

## Screenshots

<img width="1294" alt="image" src="https://github.com/justinchuby/model-explorer-onnx/assets/11205048/ed7e1eee-a693-48bd-811d-b384f784ef9b">

<img width="1291" alt="image" src="https://github.com/justinchuby/model-explorer-onnx/assets/11205048/b266d8e9-9760-4860-a0a7-eda1de31e1a1">
